@@ -1,13 +1,16 @@
-# Copyright 2009-2012 Ram Rachum.
+# Copyright 2009-2013 Ram Rachum.
 # This program is distributed under the MIT license.
 
 '''Testing module for `python_toolbox.monkeypatching_tools`.'''
 
 from __future__ import with_statement
 
+import uuid
+
 from python_toolbox import cute_testing
 
 from python_toolbox import monkeypatching_tools
+from python_toolbox import caching
 
 
 def test():
@@ -35,6 +38,27 @@ def test():
     del meow, woof
     
     
+def test_monkeypatch_cached_property():
+
+    class A(object):
+        pass
+
+    @monkeypatching_tools.monkeypatch_method(A)
+    @caching.CachedProperty
+    def meow(a):
+        return (type(a), uuid.uuid4().hex)
+    
+    a0 = A()
+    assert a0.meow == a0.meow == a0.meow == a0.meow
+    
+    a1 = A()
+    assert a1.meow == a1.meow == a1.meow == a1.meow
+    
+    assert a0.meow != a1.meow
+    assert a0.meow[0] == a1.meow[0] == A
+    
+    
+    
 def test_helpful_message_when_forgetting_parentheses():
     '''Test user gets a helpful exception when when forgetting parentheses.'''
 
